@@ -94,7 +94,7 @@ class Eriadan(_BasicScraper):
     prevSearch = compile(tagre("a", "href", r'([^"]+)', after="prev"))
     help = 'Index format: yyyy/mm/dd/nnn (unpadded)'
 
-    def shouldSkipUrl(self, url):
+    def shouldSkipUrl(self, url, data):
         return url in (
              self.stripUrl % "2013/04/02/istruzioni-per-il-non-uso", # video
         )
@@ -193,7 +193,9 @@ class EvilInc(_BasicScraper):
     url = 'http://evil-inc.com/'
     stripUrl = url + 'comic/%s'
     firstStripUrl = stripUrl % 'monday-3'
-    imageSearch = compile(tagre("img", "src", r'(http://i\d\.wp\.com/evil-inc\.com/wp-content/uploads/[^"]+)'))
+    imageSearch = compile(tagre("div", "id", "comic") +
+        r'\s*.*\s*' + #filter out the variant href tag
+        tagre("img", "src", r'(http://i\d\.wp\.com/evil-inc\.com/wp-content/uploads/[^"]+)'))
     prevSearch = compile(tagre("span", "class", "mininav-prev") +
       tagre("a", "href", r'([^"]+)'))
     help = 'Index format: stripname'
