@@ -113,7 +113,7 @@ class FonFlatter(_BasicScraper):
     prevSearch = compile(tagre("a", "href", r'(%s[^"]+)' % rurl, after="prev"))
     help = 'Index format: yyyy/mm/dd/number-stripname'
 
-    def shouldSkipUrl(self, url):
+    def shouldSkipUrl(self, url, data):
         return url in (
             self.stripUrl % "2006/11/30/adventskalender",
             self.stripUrl % "2006/09/21/danke",
@@ -147,7 +147,7 @@ class FoulLanguage(_BasicScraper):
     url = 'http://www.fowllanguagecomics.com/'
     stripUrl = url + 'comic/%s'
     firstStripUrl =  stripUrl % 'part-of-the-process'
-    imageSearch = compile(tagre("img", "src", r'(http://i\d\.wp\.com/www\.fowllanguagecomics\.com/wp-content/uploads/\d+/\d+/[^"]+\.[a-z]+)', after="comic"))
+    imageSearch = compile(tagre("img", "src", r'(http://i\d\.wp\.com/www\.fowllanguagecomics\.com/wp-content/uploads/\d+/\d+/[^"]+\.[a-z]+).*'))
     prevSearch = compile(tagre("a", "href", r'([^"]+)', after="comic-nav-previous"))
     help = 'Index format: yyyy/mm/stripname'
 
@@ -164,8 +164,11 @@ class FredoAndPidjin(_BasicScraper):
     url = 'http://www.pidjin.net/'
     stripUrl = url + '%s/'
     firstStripUrl = stripUrl % '2006/02/19/goofy-monday'
-    help = 'Index format: yyyy/mm/dd/name'
-    imageSearch = compile(tagre('img', 'src', '(http://cdn\.pidjin\.net/wp-content/uploads/\d+/\d+/[^"]+\.[a-z]+)'))
+    help = 'Index format: yyyy/mm/dd/number-index'
+    imageSearch = (
+        compile(tagre('img', 'src', '(http://cdn\.pidjin\.net/wp-content/uploads/\d+/\d+/\d+[^"]+\.[a-z]+)')),
+        compile(tagre('img', 'src', '(http://cdn\.pidjin\.net/wp-content/uploads/old/[^"]+\.[a-z]+)')),
+    )
     multipleImagesPerStrip = True
     prevSearch = compile(tagre('a', 'href', '([^"]+)')+"Prev</a>")
     starter = indirectStarter(url,
