@@ -111,22 +111,22 @@ class GirlGenius(_BasicScraper):
     stripUrl = url + '?date=%s'
     firstStripUrl = stripUrl % '20021104'
     imageSearch = compile(tagre("img", "src", r"(%sggmain/strips/[^']*)" % rurl, quote="'"))
-    prevSearch = compile(tagre("a", "href", r"(%s[^']+)" % rurl, quote="'") +
-        tagre("img", "alt", "The Previous Comic", quote="'"))
+    prevSearch = compile(tagre("a", "id", "topprev", quote="\"",
+                            before=r"(%s[^\"']+)" % rurl))
+    multipleImagesPerStrip = True
     help = 'Index format: yyyymmdd'
 
-
 class GirlsWithSlingshots(_BasicScraper):
     url = 'http://www.girlswithslingshots.com/'
     rurl = escape(url)
-    stripUrl = url + 'comic/gws%s/'
-    firstStripUrl = stripUrl % '1'
+    stripUrl = url + 'comic/%s/'
+    firstStripUrl = stripUrl % 'gws1'
     imageSearch = (
         compile(tagre("img", "src", r'(%scomics/[^"]+)' % rurl)),
         compile(tagre("img", "src", r'(http://cdn\.girlswithslingshots\.com/comics/[^"]+)')),
     )
     prevSearch = compile(tagre("a", "href", r'(%scomic/[^"]+)' % rurl, after="prev"))
-    help = 'Index format: nnn'
+    help = 'Index format: stripname'
 
 
 class GlassHalfEmpty(_BasicScraper):
