@@ -5,7 +5,7 @@
 from re import compile, escape
 from ..scraper import _BasicScraper
 from ..helpers import indirectStarter
-from ..util import tagre, urlopen
+from ..util import tagre
 
 
 class OctopusPie(_BasicScraper):
@@ -44,12 +44,18 @@ class Oglaf(_BasicScraper):
     help = 'Index format: stripname'
     adult = True
 
-    @classmethod
-    def starter(cls):
-        # click the "I am 18" button
-        data = {"over18": "&nbsp;"}
-        urlopen(cls.url, cls.session, data=data, referrer=cls.url)
-        return cls.url
+
+
+class OhJoySexToy(_BasicScraper):
+    url = 'http://www.ohjoysextoy.com/'
+    rurl = escape(url)
+    stripUrl = url + '%s/'
+    firstStripUrl = stripUrl % 'introduction'
+    imageSearch =  compile(tagre("div", "class", r'comicpane') + "\s*.*\s*" + tagre("img", "src", r'(%scomics/[^"]+)' % rurl))
+    prevSearch = compile(tagre("a", "href", r'(%s[^"]+)' % rurl, after='navi navi-prev'))
+    textSearch = compile(tagre("div", "class", r'comicpane') + "\s*.*\s*" + tagre("img", "alt", r'([^"]+)'))
+    help = 'Index Format: name'
+    adult = True
 
 
 class OkCancel(_BasicScraper):
