@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-1 -*-
 # Copyright (C) 2004-2005 Tristan Seligmann and Jonathan Jacobs
-# Copyright (C) 2012-2013 Bastian Kleineidam
+# Copyright (C) 2012-2014 Bastian Kleineidam
 
 from re import compile, escape
 from ..scraper import _BasicScraper
@@ -11,7 +11,7 @@ class QuestionableContent(_BasicScraper):
     url = 'http://www.questionablecontent.net/'
     stripUrl = url + 'view.php?comic=%s'
     firstStripUrl = stripUrl % '1'
-    imageSearch = compile(tagre("img", "src", r'([^"]+/comics/[^"]+)', before="strip"))
+    imageSearch = compile(tagre("img", "src", r'([^"]+/comics/[^"]+)'))
     prevSearch = compile(tagre("a", "href", r'(view\.php\?comic=\d+)') + 'Previous')
     help = 'Index format: n (unpadded)'
 
