@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-1 -*-
 # Copyright (C) 2004-2005 Tristan Seligmann and Jonathan Jacobs
-# Copyright (C) 2012-2013 Bastian Kleineidam
+# Copyright (C) 2012-2014 Bastian Kleineidam
 
 from re import compile, escape
 from ..scraper import _BasicScraper
@@ -49,6 +49,16 @@ class RedMeat(_BasicScraper):
     def namer(cls, imageUrl, pageUrl):
         return imageUrl.split('/')[-2]
 
+class RedsPlanet(_BasicScraper):
+    description = u"Red's Planet"
+    url = 'http://www.redsplanet.com/comic/'
+    rurl = escape(url)
+    stripUrl = url + 'rp/%s/'
+    firstStripUrl = stripUrl % 'pro/prologue-01'
+    imageSearch = compile(tagre("img", "src", r'(%scomics/\d+-\d+-\d+_[^"/]+)' % rurl))
+    prevSearch = compile(tagre("a", "href", r'(%srp/[^"/]+/[^"/]+/)' % rurl))
+    help = 'Index format: chapter/stripname'
+
 
 class RedString(_BasicScraper):
     description = u'A web comics about love and growing up. Art by Gina Biggs.'
@@ -60,6 +70,18 @@ class RedString(_BasicScraper):
     help = 'Index format: nnn'
 
 
+class RomanticallyApocalyptic(_BasicScraper):
+    description = u'Romantically Apocalyptic'
+    url = 'http://romanticallyapocalyptic.com/'
+    rurl = escape(url)
+    stripUrl = url + '%s/'
+    firstStripUrl = stripUrl % '1'
+    imageSearch = compile(tagre("img", "src", r'(%sart/\d+[^"]+)' % rurl))
+    prevSearch = compile(tagre("a", "href", r'(%s\d+[^"]+)' % rurl)+"\s*"+tagre('span', 'class', 'spritePrevious'))
+    help = 'Index format: n'
+    adult = True
+
+
 class Roza(_BasicScraper):
     url = 'http://www.junglestudio.com/roza/index.php'
     stripUrl = url + '?date=%s'
