@@ -28,6 +28,15 @@ class SabrinaOnline(_BasicScraper):
         archivepages = search.findall(data)
         return cls.url + archivepages[-1]
 
+class SafelyEndangered(_BasicScraper):
+    description = u''
+    url = 'http://www.safelyendangered.com/'
+    stripUrl = url + 'comic/%s'
+    firstStripUrl =  stripUrl % 'ignored'
+    imageSearch = compile(tagre("img", "src", r'(http://www\.safelyendangered\.com/wp-content/uploads/\d+/\d+/[^"]+\.[a-z]+).*'))
+    prevSearch = compile(tagre("a", "href", r'([^"]+)', after="navi navi-prev"))
+    textSearch = compile(tagre("img", "title", r'([^"]+)', before=r'http://www\.safelyendangered\.com/wp-content/uploads'))
+    help = 'Index format: yyyy/mm/stripname'
 
 class SailorsunOrg(_BasicScraper):
     url = 'http://sailorsun.org/'
@@ -83,7 +92,7 @@ class ScandinaviaAndTheWorld(_BasicScraper):
     description = u'Scandinavia and the World'
     url = 'http://satwcomic.com/'
     rurl = escape(url)
-    stripUrl = url + '%s/'
+    stripUrl = url + '%s'
     firstStripUrl = stripUrl % 'sweden-denmark-and-norway'
     imageSearch = compile(tagre("img", "src", r'(%sart/[^"/]+)' % rurl))
     prevSearch = compile(tagre("a", "href", r'(%s[^"/]+)' % rurl)+"\s*"+tagre('span', 'class', 'spritePrevious'))
@@ -291,6 +300,7 @@ class SluggyFreelance(_BasicScraper):
     stripUrl = url + 'comics/archives/daily/%s'
     imageSearch = compile(r'<img src="(/images/comics/.+?)"')
     prevSearch = compile(r'<a href="(.+?)"[^>]+?><span class="ui-icon ui-icon-seek-prev">')
+    multipleImagesPerStrip = True
     help = 'Index format: yymmdd'
 
 
@@ -304,7 +314,7 @@ class SMBC(_BasicScraper):
     prevSearch = compile(tagre("a", "href", r'([^"]+)#comic', after="backRollover"))
     help = 'Index format: nnnn'
 
-    def shouldSkipUrl(self, url):
+    def shouldSkipUrl(self, url, data):
         """Skip promo or missing update pages."""
         return url in (
             self.stripUrl % '2865',
@@ -346,7 +356,7 @@ class SnowFlakes(_BasicScraper):
         ext = imageUrl.rsplit('.', 1)[1]
         return "SnowFlakes-%d.%s" % (index, ext)
 
-    def shouldSkipUrl(self, url):
+    def shouldSkipUrl(self, url, data):
         """Skip pages without images."""
         return url in (
             self.stripUrl % ('279', '2'), # no comic
@@ -464,8 +474,8 @@ class StandStillStaySilent(_BasicScraper):
     rurl = escape(url)
     stripUrl = url + '?page=%s'
     firstStripUrl = stripUrl % '1'
-    imageSearch = compile(tagre("img", "src", r"(comicpages/[^']+)", before="comicnormal", quote="'"))
-    prevSearch = compile(tagre("a", "href", r"([^']+)", quote="'") + tagre("div", "id", r'navprev', quote="'"))
+    imageSearch = compile(tagre("img", "src", r'(comicpages/[^"]+)', before="comicnormal"))
+    prevSearch = compile(tagre("a", "href", r"([^']+)", quote="'") + tagre("div", "id", r'navprev'))
     help = 'Index Format: number'
     description = u'"Stand Still. Stay Silent" is a post-apocalyptic adventure story with a rather light tone and careless pace.'
 
@@ -525,7 +535,7 @@ class StuffNoOneToldMe(_BasicScraper):
         parts, imagename = imageUrl.rsplit('/', 1)
         return '%s-%s-%s-%s' % (year, month, stripname, imagename)
 
-    def shouldSkipUrl(self, url):
+    def shouldSkipUrl(self, url, data):
         """Skip pages without images."""
         return url in (
             self.stripUrl % '2012/08/self-rant', # no comic
