@@ -5,7 +5,7 @@
 from re import compile, escape, IGNORECASE
 from ..scraper import _BasicScraper
 from ..helpers import indirectStarter
-from ..util import tagre
+from ..util import tagre, fetchUrl, getPageContent
 
 
 class TheBrads(_BasicScraper):
@@ -59,6 +59,27 @@ class TheGamerCat(_BasicScraper):
     prevSearch = compile(tagre("a", "href", r'(%s\d+/\d+/[^"/]+/)' % rurl , after="navi navi-prev"))
     help = 'Index format: yyyy/mm/mmddyyyy'
 
+
+class TheGentlemansArmchair(_BasicScraper):
+    url = 'http://thegentlemansarmchair.com/'
+    rurl = escape(url)
+    stripUrl = url + 'comic/%s'
+    firstStripUrl = stripUrl % 'dora-the-explorer/'
+    imageSearch =  compile(tagre("div", "id", r'comic') + "\s*.*\s*" + tagre("img", "src", r'(%swp-content/uploads/\d+/\d+/[^"]+)' % rurl))
+    prevSearch = compile(tagre("a", "href", r'(%s[^"]+)' % rurl, after='navi-prev'))
+    textSearch = compile(r'<h3 class="comic-post-widget-title">(.+)</h3>')
+    help = 'Index Format: name'
+
+
+class TheLandscaper(_BasicScraper):
+    url = 'http://landscaper.visual-assault.net/comic/latest'
+    rurl = escape(url)
+    stripUrl = url + 'comic/%s'
+    firstStripUrl = stripUrl % '1'
+    imageSearch = compile(tagre("img", "src", r'(/comics/comic/comic_page/[^"]+)'))
+    prevSearch = compile(tagre("a", "href", r'(/comic/[^"]+)')+'&lsaquo; Previous')
+    help = 'Index format: name'
+
 class TheNoob(_BasicScraper):
     url = 'http://www.thenoobcomic.com/index.php'
     stripUrl = url + '?pos=%s'
@@ -146,7 +167,7 @@ class ToonHole(_BasicScraper):
     prevSearch = compile(tagre("a", "href", r'(%s\d+/\d+/[^"]+)' % rurl, after="prev"))
     help = 'Index format: yyyy/mm/stripname'
 
-    def shouldSkipUrl(self, url):
+    def shouldSkipUrl(self, url, data):
         return url in (self.stripUrl % "2013/03/if-game-of-thrones-was-animated",)
 
 
@@ -189,6 +210,33 @@ class TheOuterQuarter(_BasicScraper):
     help = 'Index format: nnn'
 
 
+class TheThinHLine(_BasicScraper):
+    description = u'the thin H line. Proudly mediocre. NSFW.'
+    url = 'http://thinhline.tumblr.com/'
+    rurl = escape(url)
+    stripUrl = url + 'post/%s'
+    firstStripUrl = stripUrl % '3517345105'
+    imageSearch = compile(tagre('img', 'data-src', r'([^"]+media.tumblr.com/[^"]+)', before='content-image'))
+    prevSearch = compile(tagre("a", "href", r'([^"]+)') + '&gt;</a>')
+    starter = indirectStarter(url, compile(tagre("a", "href", r'([^"]+)', after='class="timestamp"')))
+    adult = True
+
+    indirectImageSearch = compile(tagre('a', 'href', r'(%simage/\d+)' % rurl))
+
+    def getComicStrip(self, url, data, baseUrl):
+        """The comic strip image is in a separate page."""
+        pageUrl = fetchUrl(url, data, baseUrl, self.indirectImageSearch)
+        pageData, pageBaseUrl = getPageContent(pageUrl, self.session)
+        return super(TheThinHLine, self).getComicStrip(pageUrl, pageData, pageBaseUrl)
+
+    @classmethod
+    def namer(cls, imageUrl, pageUrl):
+        """Use page URL sequence which is apparently increasing."""
+        num = pageUrl.split('/')[-1]
+        ext = imageUrl.rsplit('.', 1)[1]
+        return "thethinhline-%s.%s" % (num, ext)
+
+
 class ThreePanelSoul(_BasicScraper):
     url = 'http://threepanelsoul.com/'
     rurl = escape(url)
