@@ -270,10 +270,12 @@ def unescape(text):
 _nopathquote_chars = "-;/=,~*+()@!"
 
 def normaliseURL(url):
-    """Removes any leading empty segments to avoid breaking urllib2; also replaces
-    HTML entities and character references.
+    """Normalising
+    - strips and leading or trailing whitespace,
+    - replaces HTML entities and character references,
+    - removes any leading empty segments to avoid breaking urllib2.
     """
-    url = unicode_safe(url)
+    url = unicode_safe(url).strip()
     # XXX: brutal hack
     url = unescape(url)
 
@@ -303,7 +305,7 @@ def check_robotstxt(url, session):
     roboturl = get_roboturl(url)
     rp = get_robotstxt_parser(roboturl, session=session)
     if not rp.can_fetch(UserAgent, str(url)):
-        raise IOError("%s is disallowed by robots.txt" % url)
+        raise IOError("%s is disallowed by %s" % (url, roboturl))
 
 
 @memoized
@@ -327,10 +329,10 @@ def get_robotstxt_parser(url, session=None):
 
 def urlopen(url, session, referrer=None, max_content_bytes=None,
             timeout=ConnectionTimeoutSecs, raise_for_status=True,
-            stream=False, data=None):
+            stream=False, data=None, useragent=UserAgent):
     """Open an URL and return the response object."""
     out.debug(u'Open URL %s' % url)
-    headers = {'User-Agent': UserAgent}
+    headers = {'User-Agent': useragent}
     if referrer:
         headers['Referer'] = referrer
     out.debug(u'Sending headers %s' % headers, level=3)
