@@ -6,7 +6,7 @@ d=$(dirname $0)
 if [ $# -ge 1 ]; then
   list="$*"
 else
-  list="creators gocomics drunkduck comicgenesis keenspot smackjeeves arcamax comicfury"
+  list="creators gocomics comicgenesis keenspot smackjeeves arcamax comicfury"
 fi
 for script in $list; do
   echo "Executing ${script}.py"
