@@ -9,7 +9,7 @@ d=$(dirname $0)
 if [ $# -ge 1 ]; then
   list="$*"
 else
-  list="creators gocomics drunkduck comicgenesis keenspot smackjeeves arcamax comicfury"
+  list="creators gocomics comicgenesis keenspot smackjeeves arcamax comicfury"
 fi
 for script in $list; do
   target="${d}/../dosagelib/plugins/${script}.py"
